@@ -78,9 +78,10 @@ const (
 )
 
 var (
-	vmnameLinuxRegexp      = regexp.MustCompile(k8sLinuxVMNamingFormat)
-	vmnameWindowsRegexp    = regexp.MustCompile(k8sWindowsVMNamingFormat)
-	oldvmnameWindowsRegexp = regexp.MustCompile(k8sWindowsOldVMNamingFormat)
+	vmnameLinuxRegexp        = regexp.MustCompile(k8sLinuxVMNamingFormat)
+	vmnameWindowsRegexp      = regexp.MustCompile(k8sWindowsVMNamingFormat)
+	oldvmnameWindowsRegexp   = regexp.MustCompile(k8sWindowsOldVMNamingFormat)
+	azureResourceGroupNameRE = regexp.MustCompile(`.*/subscriptions/(?:.*)/resourceGroups/(.+)/providers/(?:.*)`)
 )
 
 //AzUtil consists of utility functions which utilizes clients to different services.
@@ -251,7 +252,7 @@ func normalizeForK8sVMASScalingUp(templateMap map[string]interface{}) error {
 		resourceType, ok := resourceMap[typeFieldName].(string)
 		if ok && resourceType == nsgResourceType {
 			if nsgIndex != -1 {
-				err := fmt.Errorf("Found 2 resources with type %s in the template. There should only be 1", nsgResourceType)
+				err := fmt.Errorf("found 2 resources with type %s in the template. There should only be 1", nsgResourceType)
 				klog.Errorf(err.Error())
 				return err
 			}
@@ -259,7 +260,7 @@ func normalizeForK8sVMASScalingUp(templateMap map[string]interface{}) error {
 		}
 		if ok && resourceType == rtResourceType {
 			if rtIndex != -1 {
-				err := fmt.Errorf("Found 2 resources with type %s in the template. There should only be 1", rtResourceType)
+				err := fmt.Errorf("found 2 resources with type %s in the template. There should only be 1", rtResourceType)
 				klog.Warningf(err.Error())
 				return err
 			}
@@ -288,7 +289,7 @@ func normalizeForK8sVMASScalingUp(templateMap map[string]interface{}) error {
 
 	indexesToRemove := []int{}
 	if nsgIndex == -1 {
-		err := fmt.Errorf("Found no resources with type %s in the template. There should have been 1", nsgResourceType)
+		err := fmt.Errorf("found no resources with type %s in the template. There should have been 1", nsgResourceType)
 		klog.Errorf(err.Error())
 		return err
 	}
@@ -435,7 +436,7 @@ func k8sLinuxVMNameParts(vmName string) (poolIdentifier, nameSuffix string, agen
 	vmNum, err := strconv.Atoi(vmNameParts[k8sLinuxVMAgentIndexArrayIndex])
 
 	if err != nil {
-		return "", "", -1, fmt.Errorf("Error parsing VM Name: %v", err)
+		return "", "", -1, fmt.Errorf("error parsing VM Name: %v", err)
 	}
 
 	return vmNameParts[k8sLinuxVMAgentPoolNameIndex], vmNameParts[k8sLinuxVMAgentClusterIDIndex], vmNum, nil
@@ -550,7 +551,7 @@ func validateConfig(cfg *Config) error {
 	if cfg.VMType == vmTypeACS || cfg.VMType == vmTypeAKS {
 		// Cluster name is a mandatory param to proceed.
 		if cfg.ClusterName == "" {
-			return fmt.Errorf("Cluster name not set for type %+v", cfg.VMType)
+			return fmt.Errorf("cluster name not set for type %+v", cfg.VMType)
 		}
 	}
 
@@ -628,3 +629,14 @@ func isSuccessHTTPResponse(resp *http.Response, err error) (isSuccess bool, real
 	// This shouldn't happen, it only ensures all exceptions are handled.
 	return false, fmt.Errorf("failed with unknown error")
 }
+
+// convertResourceGroupNameToLower converts the resource group name in the resource ID to be lowered.
+func convertResourceGroupNameToLower(resourceID string) (string, error) {
+	matches := azureResourceGroupNameRE.FindStringSubmatch(resourceID)
+	if len(matches) != 2 {
+		return "", fmt.Errorf("%q isn't in Azure resource ID format", resourceID)
+	}
+
+	resourceGroup := matches[1]
+	return strings.Replace(resourceID, resourceGroup, strings.ToLower(resourceGroup), 1), nil
+}
